@@ -4,7 +4,7 @@ gSimplify = function(spgeom, tol, topologyPreserve=FALSE) {
 	if (is.na(topologyPreserve))
 		stop("Invalid value for topologyPreserve, must be logical")
 	
-    if (inherits(spgeom, "SpatialPolygons")) 
+    if (inherits(spgeom, "SpatialPolygons") && get_do_poly_check()) 
         spgeom <- createSPComment(spgeom)
     id = row.names(spgeom)
     return( .Call("rgeos_simplify", .RGEOS_HANDLE, spgeom, tol, id, 
@@ -18,7 +18,7 @@ gPolygonize = function( splist, getCutEdges=FALSE) {
 
 	p4slist = lapply(splist,function(x) x@proj4string)
         splist <- lapply(splist, function(s) {
-            if (inherits(s, "SpatialPolygons")) {
+            if (inherits(s, "SpatialPolygons") && get_do_poly_check()) {
                 createSPComment(s)
             } else {
                 s
@@ -61,7 +61,7 @@ TopologyFunc = function(spgeom, id, byid, func) {
         else        id = "1"
     }
     id = as.character(id)
-    if (inherits(spgeom, "SpatialPolygons")) spgeom <- createSPComment(spgeom)
+    if (inherits(spgeom, "SpatialPolygons") && get_do_poly_check()) spgeom <- createSPComment(spgeom)
     
     if ( length(id) != length(unique(id)) )
         stop("Non-unique values for id ")
